@@ -1,5 +1,5 @@
 access_export <- function(file, x, tablename = as.character(1:length(x)), uid = "", pwd = "", ...){
-  mycon <- RODBC::odbcConnectAccess(file, uid = uid, pwd = pwd, ...)
+  mycon <- RODBC::odbcConnect(file, uid = uid, pwd = pwd, ...)
   if(class(x)=="data.frame")
     RODBC::sqlSave(mycon, x, tablename=tablename[1], ...)
   else
